import { warn, } from "@vue/runtime-core";
import { Application, View } from "@nativescript/core";
import { createApp, NSVElement } from "..";
import { isObject } from "@vue/shared";
/**
 * @internal
 */
export function install(app) {
    app.config.globalProperties.$showModal = $showModal;
}
function resolveModalTarget(target) {
    if (isObject(target) && isObject(target.$el)) {
        return target.$el.nativeView;
    }
    else if (target instanceof NSVElement) {
        return target.nativeView;
    }
    else if (target instanceof View) {
        return target;
    }
    return false;
}
export async function $showModal(component, options) {
    options = Object.assign({
        target: Application.getRootView(),
    }, options);
    const modalTarget = resolveModalTarget(options.target);
    if (!modalTarget) {
        if (__DEV__) {
            warn(`could not open modal because the target does not exist`);
        }
        return false;
    }
    return new Promise((resolve) => {
        const modalApp = createApp(component, options ? options.props : null);
        let isResolved = false;
        const closeCallback = (data) => {
            if (isResolved)
                return;
            isResolved = true;
            try {
                modalContent.closeModal();
            }
            catch (e) {
                // ignore?
            }
            modalApp.unmount();
            resolve(data);
        };
        modalApp.config.globalProperties.$modal = {
            close: closeCallback,
        };
        const modalContent = modalApp.mount().$el.nativeView;
        modalTarget.showModal(modalContent, {
            ...options,
            context: null,
            closeCallback,
        });
    });
}
//# sourceMappingURL=modals.js.map